# -*- coding: utf-8 -*-
# @Time    : 2021-02-05 18:33
# @Author  : xzr
# @File    : settings
# @Software: PyCharm
# @Contact : xzregg@gmail.com
# @Desc    :


from .conf import settings